%define anolis_release 4
%define ruby_inc %(pkg-config --cflags ruby)

Name:           libselinux
Version:        3.5
Release:        %{anolis_release}%{?dist}
Summary:        SELinux library and simple utilities 

License:        LicenseRef-Fedora-Public-Domain
URL:            https://github.com/SELinuxProject/selinux/wiki
Source0:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        selinuxconlist.8
Source2:        selinuxdefcon.8
# Patch list start
Patch0001: 0001-Use-SHA-2-instead-of-SHA-1.patch
# https://github.com/SELinuxProject/selinux/commit/8e0e718bae53fff30831b92cd784151d475a20da
Patch0002: 0002-fix-build-error-because-of-swig-version-bump.patch
# Patch list end
BuildRequires: gcc make
BuildRequires: ruby-devel ruby libsepol-static >= %{version} swig pcre2-devel xz-devel
BuildRequires: python3 python3-devel python3-setuptools python3-pip python3-wheel
BuildRequires:  python3-rpm-macros
BuildRequires: systemd
Requires: libsepol >= %{version}
Requires: pcre2

%description
Security-enhanced Linux is a feature of the Linux® kernel and a number
of utilities with enhanced security functionality designed to add
mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These
architectural components provide general support for the enforcement
of many kinds of mandatory access control policies, including those
based on the concepts of Type Enforcement®, Role-based Access
Control, and Multi-level Security.

libselinux provides an API for SELinux applications to get and set
process and file security contexts and to obtain security policy
decisions.  Required for any applications that use the SELinux API.

%package utils
Summary:    SELinux libselinux utilities
Requires:   %{name} = %{version}-%{release}

%description utils
The libselinux-utils package contains the utilities

%package -n python3-libselinux
Summary:    SELinux python 3 bindings for libselinux
Requires:   %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-libselinux}
Provides:   %{name}-python3 = %{version}-%{release}
Obsoletes:  %{name}-python3 < %{version}-%{release}

%description -n python3-libselinux
The libselinux-python3 package contains python 3 bindings for developing
SELinux applications.

%package ruby
Summary:    SELinux ruby bindings for libselinux
Requires:   %{name} = %{version}-%{release}
Provides:   ruby(selinux)

%description ruby
The libselinux-ruby package contains the ruby bindings for developing
SELinux applications.

%package devel
Summary:    Header files and libraries used to build SELinux
Requires:   %{name} = %{version}-%{release}
Requires:   libsepol-devel >= 3.3-1 

%description devel
The libselinux-devel package contains the libraries and header files
needed for developing SELinux applications.

%package static
Summary:    Static libraries used to build SELinux
Requires:   %{name}-devel = %{version}-%{release}

%description static
The libselinux-static package contains the static libraries
needed for developing SELinux applications.


%prep
%autosetup -p 2 -n libselinux-%{version}

%build
export DISABLE_RPM="y"
export USE_PCRE2="y"
 
%set_build_flags
CFLAGS="$CFLAGS -fno-semantic-interposition"
 
# To support building the Python wrapper against multiple Python runtimes
# Define a function, for how to perform a "build" of the python wrapper against
# a specific runtime:
BuildPythonWrapper() {
  BinaryName=$1
 
  # Perform the build from the upstream Makefile:
  %make_build \
    PYTHON=$BinaryName \
    LIBDIR="%{_libdir}" \
    pywrap
}
 
%make_build LIBDIR="%{_libdir}" swigify
%make_build LIBDIR="%{_libdir}" all
 
BuildPythonWrapper %{__python3}
 
%make_build RUBYINC="%{ruby_inc}" SHLIBDIR="%{_libdir}" LIBDIR="%{_libdir}" LIBSEPOLA="%{_libdir}/libsepol.a" rubywrap

%install
InstallPythonWrapper() {
  BinaryName=$1
 
  make \
    PYTHON=$BinaryName \
    DESTDIR="%{buildroot}" LIBDIR="%{_libdir}" \
    SHLIBDIR="%{_lib}" BINDIR="%{_bindir}" \
    SBINDIR="%{_sbindir}" \
    LIBSEPOLA="%{_libdir}/libsepol.a" \
    install-pywrap
}
 
mkdir -p %{buildroot}%{_tmpfilesdir}
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_sbindir}
install -d -m 0755 %{buildroot}%{_rundir}/setrans
echo "d %{_rundir}/setrans 0755 root root" > %{buildroot}%{_tmpfilesdir}/libselinux.conf
 
InstallPythonWrapper %{__python3}
 
%make_install LIBDIR="%{_libdir}" SHLIBDIR="%{_libdir}" BINDIR="%{_bindir}" SBINDIR="%{_sbindir}"
make DESTDIR="%{buildroot}" RUBYINSTALL=%{ruby_vendorarchdir} install-rubywrap
 
# Nuke the files we don't want to distribute
rm -f %{buildroot}%{_sbindir}/compute_*
rm -f %{buildroot}%{_sbindir}/deftype
rm -f %{buildroot}%{_sbindir}/execcon
rm -f %{buildroot}%{_sbindir}/getenforcemode
rm -f %{buildroot}%{_sbindir}/getfilecon
rm -f %{buildroot}%{_sbindir}/getpidcon
rm -f %{buildroot}%{_sbindir}/mkdircon
rm -f %{buildroot}%{_sbindir}/policyvers
rm -f %{buildroot}%{_sbindir}/setfilecon
rm -f %{buildroot}%{_sbindir}/selinuxconfig
rm -f %{buildroot}%{_sbindir}/selinuxdisable
rm -f %{buildroot}%{_sbindir}/getseuser
rm -f %{buildroot}%{_sbindir}/togglesebool
rm -f %{buildroot}%{_sbindir}/selinux_check_securetty_context
mv %{buildroot}%{_sbindir}/getdefaultcon %{buildroot}%{_sbindir}/selinuxdefcon
mv %{buildroot}%{_sbindir}/getconlist %{buildroot}%{_sbindir}/selinuxconlist
install -d %{buildroot}%{_mandir}/man8/
install -m 644 %{SOURCE1} %{buildroot}%{_mandir}/man8/
install -m 644 %{SOURCE2} %{buildroot}%{_mandir}/man8/
rm -f %{buildroot}%{_mandir}/man8/togglesebool*

%generate_compatibility_deps
rm -f %{buildroot}%{abidir}/selinux.dump

%files
%dir %{abidir}
%license LICENSE
%{_libdir}/libselinux.so.*
%{abidir}/libselinux.dump
%dir %{_rundir}/setrans/
%{_tmpfilesdir}/libselinux.conf

%files utils
%{_sbindir}/*
%{abidir}/*-option.list
%{_mandir}/man5/*
%{_mandir}/man8/*
%lang(ru) %{_mandir}/ru/man5/*
%lang(ru) %{_mandir}/ru/man8/*

%files devel
%{_libdir}/libselinux.so
%{_libdir}/pkgconfig/libselinux.pc
%{_includedir}/selinux/
%{_mandir}/man3/*

%files static
%{_libdir}/libselinux.a

%files -n python3-libselinux
%{python3_sitearch}/selinux/
%{python3_sitearch}/selinux-%{version}*
%{python3_sitearch}/_selinux*
%{abidir}/_selinux*.dump
%{abidir}/audit2why.cpython-%{python3_version_nodots}-%{_arch}-linux-gnu.dump


%files ruby
%{ruby_vendorarchdir}/selinux.so

%changelog
* Tue Apr 01 2025 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 3.5-4
- Rebuild with new ruby
- add patch to fix build error because of swig version bump

* Tue Mar 12 2024 Bo Ren <rb01097748@alibaba-inc.com> - 3.5-3
- Rebuild with python3.11
- Fix build error

* Wed Nov 01 2023 Funda Wang <fundawang@yeah.net> - 3.5-2
- Fix build with latest python-setuptools

* Sat Feb 25 2023 Funda Wang <fundawang@yeah.net> - 3.5-1
- New version 3.5

* Fri Jan 06 2023 chen_yu_ao <m15927509890@163.com> - 3.4-3
- remove selinux.dump file

* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-2
- optimise spec file

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-1
- update to 3.4

* Thu Mar 10 2022 forrest_ly <flin@linux.alibaba.com> - 3.3-1
- Init for Anolis OS 23 
